Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Options ¶
type Options struct {
// TableName is the name of the table.
TableName string
// Name is the name of the generated file.
Name string
// Path is the dir path where to generate the migration files.
Path string
// Translator is a Fizz translator to use when asking for SQL migrations.
Translator nameable
// Type is the type of migration to generate (sql or fizz).
Type string
}
Options for the empty migration generator.
Click to show internal directories.
Click to hide internal directories.